==> ssp-center-api-0.6.23zlw-20200102.085320-8-sources.jar: cn/com/duiba/tuia/ssp/center/api/remote/RemoteMaterialService.java <==
package cn.com.duiba.tuia.ssp.center.api.remote;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.tuia.ssp.center.api.dto.*;
import cn.com.duiba.wolf.dubbo.DubboResult;

import java.util.List;

@AdvancedFeignClient
public interface RemoteMaterialService {

    DubboResult<Long> insert(MaterialDto record);

    DubboResult<Boolean> update(MaterialDto record);

    DubboResult<Boolean> delete(Long id);

    DubboResult<List<MaterialDto>> listByPage(ReqMaterialDto param);

    DubboResult<List<Long>> listIdByParam(String group, String type);

    DubboResult<Integer> countByParam(ReqMaterialDto param);

    DubboResult<List<MaterialToActDto>> list4Act(Long id, String title, String group, String type, Long msId);

    List<MaterialToActDto> newList4Act(Long id, String title, String group, String type, Long msId, String designer);

    DubboResult<List<MaterialDto>> listByMd5(MaterialDto record);

    DubboResult<MaterialDto> selectById(Long id);

    List<Long> saveBatchMaterial(List<ReqMaterialDto> list);

    boolean submitAudit(Long managerId, Long materialId);

    List<MaterialForSlot> getListForSlot(Long slotId);

    boolean materialChange();

    List<Long> saveBatchMaterialConfig(List<ReqMaterialConfigDto> list);

    boolean transferMaterialGroupToTag();

    boolean updateMaterialTag(List<String> tagIdStringList, Long materialId);

    List<MaterialToActDto> newList4ActByReqMaterialDto(ReqMaterialDto reqMaterialDto);

    /**
     * 更新素材库（只更新素材库这一张表，即tb_material，慎用）
     *
     * @param id
     * @param pictureSize
     * @return
     */
    Boolean initPictureSize(Long id, Long pictureSize);

    /**
     * 查询出所有没有大小的素材（初始化素材大小时使用）
     *
     * @return
     */
    List<MaterialDto> queryMaterialNoSize();

    boolean updateMaterialTitleAndDesc(List<MaterialDto> materialDtos);

    /**
     * 获取裁切素材列表
     *
     * @param param 查询条件
     * @return 裁切素材列表
     */
    List<MaterialCutDto> listMaterialCut(ReqMaterialCutDto param);

    /**
     * 获取裁切素材总数
     *
     * @param param 查询条件
     * @return 裁切素材总数
     */
    Integer countMaterialCut(ReqMaterialCutDto param);

    /**
     * 批量保存裁切素材
     *
     * @param records    裁切素材列表
     * @param fillStatus 是否填充数据，1：是，0：否
     * @param managerId  审核员id
     * @return 新增素材id
     */
    boolean saveBatchMaterialCut(List<ReqMaterialCutStyleDto> records, Integer fillStatus, Long managerId);

    /**
     * 获取裁切目标尺寸列表
     *
     * @return 裁切目标尺寸列表
     */
    List<MaterialCutSpecificationDto> listMaterialCutSpecification();

    /**
     * 是否可删除素材
     *
     * @param id 素材id
     * @return 删除结果
     */
    MaterialDeleteDto whetherDeleteMaterial(Long id);

    /**
     * 设置素材标签
     *
     * @param materialDtoList 素材列表
     * @return 设置标签素材列表
     */
    List<MaterialDto> setMaterialTagList(List<MaterialDto> materialDtoList);

    /**
     * 设置素材可用状态
     * @param materialToActDtoList 素材
     * @return 设置可用状态后素材
     */
    List<MaterialToActDto> setMaterialAvailableStatus(List<MaterialToActDto> materialToActDtoList);

    /**
     * @Author zhangliwei
     * @Description  订正picture_val为空的所有素材数据,只初始化一次,不要调用!!
     * @Date 16:53 2019-12-06
     * @Param []
     * @return boolean
     **/
    boolean initEmptyPictureVal();

}

==> ssp-center-api-0.6.89zlw-20200324.024200-2-sources.jar: cn/com/duiba/tuia/ssp/center/api/remote/RemoteMaterialService.java <==
package cn.com.duiba.tuia.ssp.center.api.remote;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.tuia.ssp.center.api.dto.*;
import cn.com.duiba.wolf.dubbo.DubboResult;

import java.util.List;

@AdvancedFeignClient
public interface RemoteMaterialService {

    DubboResult<Long> insert(MaterialDto record);

    DubboResult<Boolean> update(MaterialDto record);

    DubboResult<Boolean> updateMaterialDirect(MaterialDirectDto record);

    DubboResult<MaterialDirectAppDto> getDirectAppByMaterialId(Long id);

    DubboResult<Boolean> delete(Long id);

    DubboResult<List<MaterialDto>> listByPage(ReqMaterialDto param);

    DubboResult<List<Long>> listIdByParam(String group, String type);

    DubboResult<Integer> countByParam(ReqMaterialDto param);

    DubboResult<List<MaterialToActDto>> list4Act(Long id, String title, String group, String type, Long msId);

    List<MaterialToActDto> newList4Act(Long id, String title, String group, String type, Long msId, String designer);

    DubboResult<List<MaterialDto>> listByMd5(MaterialDto record);

    DubboResult<MaterialDto> selectById(Long id);

    List<Long> saveBatchMaterial(List<ReqMaterialDto> list);

    boolean submitAudit(Long managerId, Long materialId);

    List<MaterialForSlot> getListForSlot(Long slotId);

    boolean materialChange();

    List<Long> saveBatchMaterialConfig(List<ReqMaterialConfigDto> list);

    boolean transferMaterialGroupToTag();

    boolean updateMaterialTag(List<String> tagIdStringList, Long materialId);

    List<MaterialToActDto> newList4ActByReqMaterialDto(ReqMaterialDto reqMaterialDto);

    /**
     * 更新素材库（只更新素材库这一张表，即tb_material，慎用）
     *
     * @param id
     * @param pictureSize
     * @return
     */
    Boolean initPictureSize(Long id, Long pictureSize);

    /**
     * 查询出所有没有大小的素材（初始化素材大小时使用）
     *
     * @return
     */
    List<MaterialDto> queryMaterialNoSize();

    boolean updateMaterialTitleAndDesc(List<MaterialDto> materialDtos);

    /**
     * 获取裁切素材列表
     *
     * @param param 查询条件
     * @return 裁切素材列表
     */
    List<MaterialCutDto> listMaterialCut(ReqMaterialCutDto param);

    /**
     * 获取裁切素材总数
     *
     * @param param 查询条件
     * @return 裁切素材总数
     */
    Integer countMaterialCut(ReqMaterialCutDto param);

    /**
     * 批量保存裁切素材
     *
     * @param records    裁切素材列表
     * @param fillStatus 是否填充数据，1：是，0：否
     * @param managerId  审核员id
     * @return 新增素材id
     */
    List<Long> saveBatchMaterialCut(List<ReqMaterialCutStyleDto> records, Integer fillStatus, Long managerId);

    /**
     * 获取裁切目标尺寸列表
     *
     * @return 裁切目标尺寸列表
     */
    List<MaterialCutSpecificationDto> listMaterialCutSpecification();

    /**
     * 批量更新素材ids的投放状态
     * @param materialIds
     * @param enableStatus
     * @return
     */
    int batchUpdateEnableStatus(List<Long> materialIds, Integer enableStatus);

    /**
     * 是否可删除素材
     *
     * @param id 素材id
     * @return 删除结果
     */
    MaterialDeleteDto whetherDeleteMaterial(Long id);

    /**
     * 设置素材标签
     *
     * @param materialDtoList 素材列表
     * @return 设置标签素材列表
     */
    List<MaterialDto> setMaterialTagList(List<MaterialDto> materialDtoList);

    /**
     * 设置素材可用状态
     * @param materialToActDtoList 素材
     * @return 设置可用状态后素材
     */
    List<MaterialToActDto> setMaterialAvailableStatus(List<MaterialToActDto> materialToActDtoList);

    /**
     * @Author zhangliwei
     * @Description  订正picture_val为空的所有素材数据,只初始化一次,不要调用!!
     * @Date 16:53 2019-12-06
     * @Param []
     * @return boolean
     **/
    boolean initEmptyPictureVal();

    /**
     * 保存在投素材
     */
    boolean saveMaterialRelease(MaterialReleaseDTO materialReleaseDTO);

    /**
     * 删除在投素材
     */
    boolean removeMaterialRelease(MaterialReleaseDTO materialReleaseDTO);

    List<Long> getMaterialIdsByTagTitles(List<String> titles);

    /**
     * @Author zhangliwei
     * @Description  根据素材ID列表查询素材效果集合
     * @Date 14:58 2020-02-06
     * @Param [ids]
     * @return java.util.List<cn.com.duiba.tuia.ssp.center.api.dto.MaterialEffectDto>
     **/
    List<MaterialEffectDto> getMaterialEffects(List<Long> ids);
}
